@@ -13,11 +13,12 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+
 import os
 
 from cdpcli.compat import compat_open
 from cdpcli.compat import six
-from cdpcli.thirdparty import requests
+import requests
 
 
 class ResourceLoadingError(Exception):
